# Meld Language Support for VSCode and Cursor

Visual Studio Code and Cursor extension for the Meld prompt scripting language that provides:

- Hybrid syntax highlighting (Meld directives + Markdown for content)
- Intelligent autocompletion for Meld directives, variables, and commands
- Path validation according to Meld language rules
- Markdown header autocompletion in embed directives
- Hover documentation for directives
- Integration with meld-ast for accurate parsing and analysis

## Features

### Hybrid Syntax Highlighting
Combines the best of both worlds:
- Meld syntax for directives, variables, and commands
- Markdown syntax for content portions
- Properly handles single quotes, contractions, and @ symbols in text
- Special highlighting for directive blocks

### Path Validation
- Shows realtime diagnostics for invalid paths
- Validates according to Meld's path rules
- Provides helpful error messages for fixing path issues

### Intelligent Autocompletion
- After typing `@`: Shows available directives
- After typing `${`: Shows available text variables
- After typing `#{`: Shows available data variables
- After typing `$` (not followed by `{`): Shows available path variables
- Inside `@run [`: Shows common commands
- After `@embed [filepath #`: Shows markdown headers from the referenced file

### Import Resolution
- Autocompletes variables from imported files
- Shows source information in completions

## Installation

### Visual Studio Code

#### From Marketplace
Once published:
```bash
code --install-extension meld.meld-vscode
```

Or search for "Meld Language Support" in the Extensions view.

#### From VSIX
```bash
code --install-extension meld-vscode-0.1.0.vsix
```

Or:
1. Open VSCode
2. View → Extensions (or press Ctrl+Shift+X)
3. Click "..." at the top of the Extensions view
4. Select "Install from VSIX..."
5. Choose the downloaded VSIX file

### Cursor

#### From VSIX
```bash
cursor --install-extension meld-vscode-0.1.0.vsix
```

Or:
1. Open Cursor
2. View → Extensions (or press Ctrl+Shift+X)
3. Click "..." at the top of the Extensions view
4. Select "Install from VSIX..."
5. Choose the downloaded VSIX file

## Usage

The extension activates automatically for `.meld`, `.meld.md`, `.mll`, and `.mll.md` files.

For best results when writing Meld files:
- Use `$PROJECTPATH/` or `$HOMEPATH/` for paths (not relative paths)
- Follow Meld's path syntax for proper validation
- Structure your document with Markdown for content portions

## Development

### Setup
```bash
git clone https://github.com/username/meld-vscode.git
cd meld-vscode
npm install
```

### Build
```bash
npm run build
```

### Package
```bash
npm run package
```

### Testing
The `src/test` directory contains sample Meld files to test various features.

### Contributing
See [CONTRIBUTING.md](CONTRIBUTING.md) for guidelines.

## License
[MIT](LICENSE)
